==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LocalityLoadBalancerSettingFailoverBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LocalityLoadBalancerSettingFailoverBuilder extends LocalityLoadBalancerSettingFailoverFluentImpl<LocalityLoadBalancerSettingFailoverBuilder> implements VisitableBuilder<LocalityLoadBalancerSettingFailover,LocalityLoadBalancerSettingFailoverBuilder>{
  public LocalityLoadBalancerSettingFailoverBuilder() {
    this(false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(Boolean validationEnabled) {
    this(new LocalityLoadBalancerSettingFailover(), validationEnabled);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent) {
    this(fluent, false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LocalityLoadBalancerSettingFailover(), validationEnabled);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent,LocalityLoadBalancerSettingFailover instance) {
    this(fluent, instance, false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent,LocalityLoadBalancerSettingFailover instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailover instance) {
    this(instance,false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailover instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  LocalityLoadBalancerSettingFailoverFluent<?> fluent;
  Boolean validationEnabled;
  public LocalityLoadBalancerSettingFailover build() {
    LocalityLoadBalancerSettingFailover buildable = new LocalityLoadBalancerSettingFailover(fluent.getFrom(),fluent.getTo());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LocalityLoadBalancerSettingFailoverBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LocalityLoadBalancerSettingFailoverBuilder extends LocalityLoadBalancerSettingFailoverFluent<LocalityLoadBalancerSettingFailoverBuilder> implements VisitableBuilder<LocalityLoadBalancerSettingFailover,LocalityLoadBalancerSettingFailoverBuilder>{
  public LocalityLoadBalancerSettingFailoverBuilder() {
    this(false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(Boolean validationEnabled) {
    this(new LocalityLoadBalancerSettingFailover(), validationEnabled);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent) {
    this(fluent, false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LocalityLoadBalancerSettingFailover(), validationEnabled);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent,LocalityLoadBalancerSettingFailover instance) {
    this(fluent, instance, false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailoverFluent<?> fluent,LocalityLoadBalancerSettingFailover instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LocalityLoadBalancerSettingFailover());

    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailover instance) {
    this(instance,false);
  }
  public LocalityLoadBalancerSettingFailoverBuilder(LocalityLoadBalancerSettingFailover instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LocalityLoadBalancerSettingFailover());

    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  LocalityLoadBalancerSettingFailoverFluent<?> fluent;
  Boolean validationEnabled;
  public LocalityLoadBalancerSettingFailover build() {
    LocalityLoadBalancerSettingFailover buildable = new LocalityLoadBalancerSettingFailover(fluent.getFrom(),fluent.getTo());
    return buildable;
  }
  
}
